@@ -1,5 +1,3 @@
-import os
-import datetime
 import pkg_resources
 from requests import Session
 from requests.adapters import HTTPAdapter
@@ -7,25 +5,6 @@ from requests.packages.urllib3.poolmanager import PoolManager
 from requests.packages.urllib3.util.retry import Retry
 from urllib.parse import urljoin
 
-from snitch_ai.internal.jwt import decode_token
-
-_last_checked_access_token = None
-
-def _verify_access_token(access_token):
-    try:
-        claims = decode_token(access_token)
-
-        if not "iat" in claims or int(claims["iat"]) > datetime.datetime.utcnow().timestamp():
-            raise Exception("Access token is not yet valid.")
-
-        if not "exp" in claims or int(claims["exp"]) < datetime.datetime.utcnow().timestamp():
-            raise Exception("Access token has expired and is no longer valid.")
-    except:
-        raise Exception("Access token is not valid. Please double-check value and try again.")
-
-    global _last_checked_access_token
-    _last_checked_access_token = access_token
-
 
 # ignore hostname so long as the certificate matches the expected certificate since we do not know
 # where the client is potentially hosting their LocalApi
@@ -52,10 +31,6 @@ class ApiClient(Session):
         if not access_token or len(access_token) == 0:
             raise Exception("You must set the snitch_ai.access_token variable to your access token before you can perform any API calls.")
 
-        if access_token != _last_checked_access_token:
-            #perform local token verification
-            _verify_access_token(access_token)
-
         headers = {}
         if "headers" in kwargs:
             headers = kwargs["headers"]
