@@ -14,6 +14,7 @@ from snitch_ai.internal.quality_analysis import QualityAnalysis
 from snitch_ai.internal.drift_analysis import DriftAnalysis
 from snitch_ai.internal.analysis_status import AnalysisState
 
+
 def _save_tf_model(model, path):
     path += ".h5"
     model.save(path, save_format="h5")
@@ -35,7 +36,7 @@ def _save_xgboost_model(model, path):
 def _save_model_to_path(model, path):
     model_type = str(type(model))
 
-    if "tensorflow." in model_type:
+    if "tensorflow." in model_type or "keras." in model_type:
         return _save_tf_model(model, path)
 
     if "xgboost." in model_type:
@@ -55,14 +56,18 @@ def _save_dataset_to_path(dataset, path):
 
 def _upload_quality_analysis_file(project_id, quality_id, client, file_name, file_path):
     with open(file_path, "rb") as f:
-        resp = client.patch(f"project/{project_id}/quality/{quality_id}", files={file_name: f})
+        resp = client.patch(
+            f"project/{project_id}/quality/{quality_id}", files={file_name: f}
+        )
         if resp.status_code != 200:
             raise Exception(f"Error uploading file: {resp.text}")
 
 
 def _upload_drift_analysis_file(project_id, drift_id, client, file_name, file_path):
     with open(file_path, "rb") as f:
-        resp = client.patch(f"project/{project_id}/drift/{drift_id}", files={file_name: f})
+        resp = client.patch(
+            f"project/{project_id}/drift/{drift_id}", files={file_name: f}
+        )
         if resp.status_code != 200:
             raise Exception(f"Error uploading file: {resp.text}")
 
@@ -84,16 +89,16 @@ def _wait_on_analysis_completion(analysis: Union[QualityAnalysis, DriftAnalysis]
         elif status.state == AnalysisState.ERROR:
             raise Exception(f"The analysis failed due to an error: {status.error}")
         elif status.state == AnalysisState.UNKNOWN:
-            raise Exception("Error while waiting on analysis: analysis hasn't been started yet.")
+            raise Exception(
+                "Error while waiting on analysis: analysis hasn't been started yet."
+            )
 
 
 class Project:
-
     def __init__(self, project_id: GUID, name: str):
         self.project_id = project_id
         self.name = name
 
-
     def get_quality_analysis(self, quality_id) -> QualityAnalysis:
         """
         Recovers a quality analysis by ID.
@@ -110,8 +115,16 @@ class Project:
 
         return QualityAnalysis(self.project_id, GUID(quality_obj["id"]))
 
-
-    def run_quality_analysis(self, model, train_x, train_y, test_x, test_y, label: str = None, no_wait: bool = False) -> QualityAnalysis:
+    def run_quality_analysis(
+        self,
+        model,
+        train_x,
+        train_y,
+        test_x,
+        test_y,
+        label: str = None,
+        no_wait: bool = False,
+    ) -> QualityAnalysis:
         """
         Runs a Quality analysis using the specified parameters.
         :param model: The model file. Supported types are Tensorflow, SciKit-Learn and XGBoost.
@@ -126,38 +139,50 @@ class Project:
         client = ApiClient()
 
         if not label:
-            label = f"Quality Analysis {datetime.datetime.now().strftime('%Y-%m-%d %H:%M')}"
+            label = (
+                f"Quality Analysis {datetime.datetime.now().strftime('%Y-%m-%d %H:%M')}"
+            )
 
         # create quality analysis
-        resp = client.post(f"/project/{self.project_id}/quality", data={ "label": label })
+        resp = client.post(f"/project/{self.project_id}/quality", data={"label": label})
         if resp.status_code != 201:
             raise Exception(f"Error creating quality analysis: {resp.text}")
 
         quality_obj = resp.json()
-        quality_id = quality_obj["id"];
+        quality_id = quality_obj["id"]
 
         # upload files
         temp_dir = tempfile.mkdtemp(prefix="snitch_ai_")
         try:
             if not model is None:
                 path = _save_model_to_path(model, os.path.join(temp_dir, "model"))
-                _upload_quality_analysis_file(self.project_id, quality_id, client, "model", path)
+                _upload_quality_analysis_file(
+                    self.project_id, quality_id, client, "model", path
+                )
 
             if not train_x is None:
                 path = _save_dataset_to_path(train_x, os.path.join(temp_dir, "train_x"))
-                _upload_quality_analysis_file(self.project_id, quality_id, client, "train_x", path)
+                _upload_quality_analysis_file(
+                    self.project_id, quality_id, client, "train_x", path
+                )
 
             if not train_y is None:
                 path = _save_dataset_to_path(train_y, os.path.join(temp_dir, "train_y"))
-                _upload_quality_analysis_file(self.project_id, quality_id, client, "train_y", path)
+                _upload_quality_analysis_file(
+                    self.project_id, quality_id, client, "train_y", path
+                )
 
             if not test_x is None:
                 path = _save_dataset_to_path(test_x, os.path.join(temp_dir, "test_x"))
-                _upload_quality_analysis_file(self.project_id, quality_id, client, "test_x", path)
+                _upload_quality_analysis_file(
+                    self.project_id, quality_id, client, "test_x", path
+                )
 
             if not test_y is None:
                 path = _save_dataset_to_path(test_y, os.path.join(temp_dir, "test_y"))
-                _upload_quality_analysis_file(self.project_id, quality_id, client, "test_y", path)
+                _upload_quality_analysis_file(
+                    self.project_id, quality_id, client, "test_y", path
+                )
         finally:
             shutil.rmtree(temp_dir)
 
@@ -173,7 +198,6 @@ class Project:
 
         return quality_analysis
 
-
     def get_drift_analysis(self, drift_id) -> DriftAnalysis:
         """
         Recovers a drift analysis by ID.
@@ -190,8 +214,9 @@ class Project:
 
         return DriftAnalysis(self.project_id, GUID(drift_obj["id"]))
 
-
-    def run_drift_analysis(self, train_x, updated_x, label: str = None, no_wait: bool = False) -> DriftAnalysis:
+    def run_drift_analysis(
+        self, train_x, updated_x, label: str = None, no_wait: bool = False
+    ) -> DriftAnalysis:
         """
         Runs a Drift analysis using the specified parameters.
         :param train_x: The training feature dataset in array format.
@@ -203,26 +228,34 @@ class Project:
         client = ApiClient()
 
         if not label:
-            label = f"Drift Analysis {datetime.datetime.now().strftime('%Y-%m-%d %H:%M')}"
+            label = (
+                f"Drift Analysis {datetime.datetime.now().strftime('%Y-%m-%d %H:%M')}"
+            )
 
         # create drift analysis
-        resp = client.post(f"/project/{self.project_id}/drift", data={ "label": label })
+        resp = client.post(f"/project/{self.project_id}/drift", data={"label": label})
         if resp.status_code != 201:
             raise Exception(f"Error creating drift analysis: {resp.text}")
 
         drift_obj = resp.json()
-        drift_id = drift_obj["id"];
+        drift_id = drift_obj["id"]
 
         # upload files
         temp_dir = tempfile.mkdtemp(prefix="snitch_ai_")
         try:
             if not train_x is None:
                 path = _save_dataset_to_path(train_x, os.path.join(temp_dir, "train_x"))
-                _upload_drift_analysis_file(self.project_id, drift_id, client, "train_x", path)
+                _upload_drift_analysis_file(
+                    self.project_id, drift_id, client, "train_x", path
+                )
 
             if not updated_x is None:
-                path = _save_dataset_to_path(updated_x, os.path.join(temp_dir, "updated_x"))
-                _upload_drift_analysis_file(self.project_id, drift_id, client, "updated_x", path)
+                path = _save_dataset_to_path(
+                    updated_x, os.path.join(temp_dir, "updated_x")
+                )
+                _upload_drift_analysis_file(
+                    self.project_id, drift_id, client, "updated_x", path
+                )
         finally:
             shutil.rmtree(temp_dir)
 
@@ -238,7 +271,6 @@ class Project:
 
         return drift_analysis
 
-
     def __str__(self):
         return f"Project {self.project_id}: {self.name}"
 
@@ -251,7 +283,7 @@ def select_project(project_name: str) -> Project:
     """
     client = ApiClient()
 
-    resp = client.post("project/select", data={ "name": project_name })
+    resp = client.post("project/select", data={"name": project_name})
     if resp.status_code != 200 and resp.status_code != 201:
         raise Exception(f"Could not select project: {resp.text}")
 
@@ -268,7 +300,7 @@ def create_project(project_name: str) -> Project:
     """
     client = ApiClient()
 
-    resp = client.post("project", data={ "name": project_name })
+    resp = client.post("project", data={"name": project_name})
     if resp.status_code != 201:
         raise Exception(f"Could not create project: {resp.text}")
 
@@ -287,7 +319,7 @@ def get_project(target: Union[str, GUID]) -> Project:
 
     json = None
     if isinstance(target, str):
-        resp = client.get("project", params={ "name": target })
+        resp = client.get("project", params={"name": target})
         if resp.status_code != 200:
             raise Exception(f"Could not find project: {resp.text}")
         json = resp.json()
